// @flow
import React from 'react';
import { connect } from 'react-redux';
import type { Dispatch } from 'redux';
import compose from 'recompose/compose';
import { withRouter, type History, type Location } from 'react-router-dom';
import { withCurrentUser } from 'src/components/withCurrentUser';
import SetUsername from './components/setUsername';
import { track, events } from 'src/helpers/analytics';
import type { UserInfoType } from 'shared/graphql/fragments/user/userInfo';
import { SERVER_URL } from 'src/api/constants';
import { setTitlebarProps } from 'src/actions/titlebar';
import { ViewGrid, CenteredGrid } from 'src/components/layout';
import { LogOutButton, Emoji, Heading, Description, Card } from './style';

type Props = {
  currentUser: UserInfoType,
  history: History,
  location: Location,
  dispatch: Dispatch<Object>,
};

class NewUserOnboarding extends React.Component<Props> {
  componentDidMount() {
    const { dispatch } = this.props;
    dispatch(
      setTitlebarProps({
        title: 'Create username',
      })
    );
  }

  saveUsername = () => {
    const { history, location } = this.props;
    const { state } = location;
    track(events.USER_ONBOARDING_SET_USERNAME);
    if (state && state.redirect) return history.replace(state.redirect);
    return history.replace('/');
  };

  render() {
    const { currentUser, history } = this.props;

    if (!currentUser) {
      history.replace('/');
      return null;
    }

    if (currentUser && currentUser.username) {
      this.saveUsername();
      return null;
    }

    const heading = 'Create a username';
    const subheading = 'You can change this at any time, so no pressure!';
    const emoji = '👋';
    return (
      <ViewGrid data-cy="new-user-onboarding">
        <CenteredGrid>
          <Card>
            <Emoji role="img" aria-label="Oops">
              {emoji}
            </Emoji>
            <Heading>{heading}</Heading>
            <Description>{subheading}</Description>

            <SetUsername user={currentUser} save={this.saveUsername} />

            <LogOutButton
              data-cy="new-user-onboarding-logout"
              target="_self"
              href={`${SERVER_URL}/auth/logout`}
            >
              Log out
            </LogOutButton>
          </Card>
        </CenteredGrid>
      </ViewGrid>
    );
  }
}

export default compose(
  withRouter,
  withCurrentUser,
  connect()
)(NewUserOnboarding);
